# social-media-cleaner
A tool to remove inappropriate content from your social media accounts.

# Installation
## With pipx (preferred)
This is a preferred way because pipx isolates each python CLI application:
```shell
pipx install smcleaner
```

## With pip
Ensure installing for a current user only to avoid system-level troubles:
```shell
pip install --user smcleaner
```

## Completion
Add it with:
```shell
smcleaner --install-completion
```
